@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.08';
+our $VERSION = '0.09';
 
 use Dist::Zilla::File::InMemory;
 
@@ -79,7 +79,7 @@ sub _write_mailmap {
     }
 
     open my $fh, '>:encoding(UTF-8)', '.mailmap';
-    for ( keys %mailmap ) {
+    for ( sort keys %mailmap ) {
         print {$fh} $_, "\n" or die $!;
     }
     close $fh;
